==> slurm-2.0.1.tar.bz2: slurm-2.0.1/src/common/daemonize.h <==
/*****************************************************************************\
 * src/slurmd/daemonize.h - function definition for making a daemon
 * $Id: daemonize.h 16616 2009-02-20 17:00:27Z jette $
 *****************************************************************************
 *  Copyright (C) 2002 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <mgrondona@llnl.gov>.
 *  CODE-OCEC-09-009. All rights reserved.
 *  
 *  This file is part of SLURM, a resource management program.
 *  For details, see <https://computing.llnl.gov/linux/slurm/>.
 *  Please also read the included file: DISCLAIMER.
 *  
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission 
 *  to link the code of portions of this program with the OpenSSL library under 
 *  certain conditions as described in each individual source file, and 
 *  distribute linked combinations including the two. You must obey the GNU 
 *  General Public License in all respects for all of the code used other than 
 *  OpenSSL. If you modify file(s) with this exception, you may extend this 
 *  exception to your version of the file(s), but you are not obligated to do 
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in 
 *  the program, then also delete it here.
 *  
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/


#ifndef _HAVE_DAEMONIZE_H
#define _HAVE_DAEMONIZE_H

/* fork process into background and inherit new session
 * if nochdir is 0, performs a chdir("/")
 * if noclose is 0, closes all fds and dups stdout/err of daemon onto /dev/null
 *
 * returns -1 on error.
 */
extern int daemon(int nochdir, int noclose);

/* Write pid into file pidfile
 */
extern int create_pidfile(const char *pidfilename);

/*
 * Attempt to read an old pid from the configured pidfile
 * Returns 0 if no pidfile exists (No running process)
 * If pidfilefd is not NULL, returns open file descriptor for
 * pidfile (when pid != 0).
 */
extern pid_t read_pidfile(const char *pidfilename, int *pidfilefd);

#endif /* !_HAVE_DAEMONIZE_H */

==> slurm-2.2.3.tar.bz2: slurm-2.2.3/src/common/daemonize.h <==
/*****************************************************************************\
 * src/slurmd/daemonize.h - function definition for making a daemon
 * $Id: daemonize.h 21754 2010-12-10 17:44:30Z da $
 *****************************************************************************
 *  Copyright (C) 2002 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <mgrondona@llnl.gov>.
 *  CODE-OCEC-09-009. All rights reserved.
 *
 *  This file is part of SLURM, a resource management program.
 *  For details, see <https://computing.llnl.gov/linux/slurm/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/


#ifndef _HAVE_DAEMONIZE_H
#define _HAVE_DAEMONIZE_H

/* fork process into background and inherit new session
 * if nochdir is 0, performs a chdir("/")
 * if noclose is 0, closes all fds and dups stdout/err of daemon onto /dev/null
 *
 * returns -1 on error.
 */
extern int daemon(int nochdir, int noclose);

/* Write pid into file pidfile if uid is not 0 change the owner of the
 * pidfile to that user.
 */
extern int create_pidfile(const char *pidfilename, uid_t uid);

/*
 * Attempt to read an old pid from the configured pidfile
 * Returns 0 if no pidfile exists (No running process)
 * If pidfilefd is not NULL, returns open file descriptor for
 * pidfile (when pid != 0).
 */
extern pid_t read_pidfile(const char *pidfilename, int *pidfilefd);

/*
 * Test for a core file limit. If small then log it.
 */
extern void test_core_limit(void);

#endif /* !_HAVE_DAEMONIZE_H */
